package appServer

import (
	"fmt"
	"github.com/kataras/iris/v12"
	"sync"
	"time"
	"xiaoxiong/internal/global"
	"xiaoxiong/internal/utils/dtk"
	"xiaoxiong/internal/utils/taobao"
)

type HomeClipboardRequest struct {
	ItemId string `json:"item_id"`
	Pid string `json:"pid"`
	RelationId string `json:"relation_id"`
	DtkAppType int8 `json:"dtk_app_type"`
	TaobaoAppType int8 `json:"taobao_app_type"`
}

type HomeClipboardResponse struct {
	DtkItemDetail *dtk.ItemDetailData `json:"dtk_item_detail"`
	TaobaoItemDetail *taobao.TbkItemInfoGet `json:"taobao_item_detail"`
	GyInfo *taobao.TbkCouponConvert `json:"gy_info"`
}

// HomeClipboard curl -H "Content-Type: application/json" -X POST -d '{"item_id": "630305425763", "pid":"111476400316", "relation_id":"", "dtk_app_type":"0" ,"taobao_app_type":"0"}' "http://127.0.0.1:8090/turnchain.homeClipboard"
func HomeClipboard(ctx iris.Context) {
	req := &HomeClipboardRequest{}
	resp := &HomeClipboardResponse{}

	err := ctx.ReadJSON(req)
	if err == nil {
		_, _ = ctx.JSON(iris.Map{"code":2001,"msg":"参数错误","data":""})
		return
	}

	global.Log.Debug(fmt.Sprintf("req:%s\n", req))

	var dtkItemDetail *dtk.ItemDetailData
	var dtkErr error
	var taobaoItemDetail *taobao.TbkItemInfoGet
	var taobaoItemDetailErr error
	var gyInfo *taobao.TbkCouponConvert
	var gyInfoErr error

	var wg sync.WaitGroup
	wg.Add(1)
	_ = global.GoPool.Submit(func() {
		global.Log.Debug("dtkItemDetail:" + time.Now().Format("2006-01-02 15:04:05.999999999"))
		dtkItemDetail, dtkErr = dtk.ItemDetail(req.ItemId, req.DtkAppType)
		wg.Done()
	})

	wg.Add(1)
	_ = global.GoPool.Submit(func() {
		global.Log.Debug("taobaoItemDetail:"+time.Now().Format("2006-01-02 15:04:05.999999999"))
		taobaoItemDetail, taobaoItemDetailErr = taobao.ItemDetail(req.ItemId, req.TaobaoAppType)
		wg.Done()
	})

	wg.Add(1)
	_ = global.GoPool.Submit(func() {
		global.Log.Debug("gyInfo:"+time.Now().Format("2006-01-02 15:04:05.999999999"))
		gyInfo, gyInfoErr = taobao.GyInfo(req.ItemId, req.Pid, req.RelationId, req.TaobaoAppType)
		wg.Done()
	})

	wg.Wait()

	resp.TaobaoItemDetail = taobaoItemDetail
	resp.GyInfo = gyInfo
	resp.DtkItemDetail = dtkItemDetail

	global.Log.Debug(fmt.Sprintf("taobaoItemDetailErr:%s\n", taobaoItemDetailErr))
	global.Log.Debug(fmt.Sprintf("dtkErr:%s\n", dtkErr))
	global.Log.Debug(fmt.Sprintf("gyInfoErr:%s\n", gyInfoErr))

	_, _ = ctx.JSON(iris.Map{"code":2000,"msg":"","data":resp})
}
