package dtk

import (
	"crypto/md5"
	"encoding/hex"
	"encoding/json"
	"fmt"
	"io/ioutil"
	"net/http"
	"net/url"
	"strconv"
	"strings"
	"time"
	"xiaoxiong/internal/global"
	"xiaoxiong/internal/utils"
)

type CommonData struct {
	appKey  string
	version string
	timer   string
	nonce   string
	signRan string
}

type ItemDetailData struct {
	RequestId string `json:"requestId"`
	Time      int64  `json:"time"`
	Code      int    `json:"code"`
	Msg       string `json:"msg"`
	Data      struct {
		Id                     int           `json:"id"`
		GoodsId                string        `json:"goodsId"`
		Title                  string        `json:"title"`
		Dtitle                 string        `json:"dtitle"`
		OriginalPrice          float64       `json:"originalPrice"`
		ActualPrice            float64       `json:"actualPrice"`
		ShopType               int           `json:"shopType"`
		GoldSellers            int           `json:"goldSellers"`
		MonthSaLes             int           `json:"monthSales"`
		TwoHoursSales          int           `json:"twoHoursSales"`
		DailySales             int           `json:"dailySales"`
		CommissionType         int           `json:"commissionType"`
		Desc                   string        `json:"desc"`
		CouponReceiveNum       int           `json:"couponReceiveNum"`
		CouponLink             string        `json:"couponLink"`
		CouponEndTime          string        `json:"couponEndTime"`
		CouponStartTime        string        `json:"couponStartTime"`
		CouponPrice            int           `json:"couponPrice"`
		CouponConditions       string        `json:"couponConditions"`
		CouponId               string        `json:"couponId"`
		ActivityType           int           `json:"activityType"`
		CreateTime             string        `json:"createTime"`
		MainPic                string        `json:"mainPic"`
		MarketingMainPic       string        `json:"marketingMainPic"`
		SellerId               string        `json:"sellerId"`
		BrandWenan             string        `json:"brandWenan"`
		Cid                    int           `json:"cid"`
		Discounts              float64       `json:"discounts"`
		CommiSsionRate         int           `json:"commissionRate"`
		CouponTotalNum         int           `json:"couponTotalNum"`
		Haitao                 int           `json:"haitao"`
		ActivityStartTime      string        `json:"activityStartTime"`
		ActivityEndTime        string        `json:"activityEndTime"`
		ShopName               string        `json:"shopName"`
		ShopLevel              int           `json:"shopLevel"`
		DescScore              float64       `json:"descScore"`
		Brand                  int           `json:"brand"`
		BrandId                int           `json:"brandId"`
		BrandName              string        `json:"brandName"`
		HotPush                int           `json:"hotPush"`
		TeamName               string        `json:"teamName"`
		ItemLink               string        `json:"itemLink"`
		Tchaoshi               int           `json:"tchaoshi"`
		DsrScore               float64       `json:"dsrScore"`
		DsrPercent             float64       `json:"dsrPercent"`
		ShipScore              float64       `json:"shipScore"`
		ShipPercent            float64       `json:"shipPercent"`
		ServiceScore           float64       `json:"serviceScore"`
		ServicePercent         float64       `json:"servicePercent"`
		Subcid                 []interface{} `json:"subcid"`
		Imgs                   string        `json:"imgs"`
		Reimgs                 string        `json:"reimgs"`
		QuanMLink              int           `json:"quanMLink"`
		HzQuanOver             int           `json:"hzQuanOver"`
		Yunfeixian             int           `json:"yunfeixian"`
		EstimateAmount         int           `json:"estimateAmount"`
		ShoPLogo               string        `json:"shopLogo"`
		SpecialText            []interface{} `json:"specialText"`
		FreeshipRemoteDistrict int           `json:"freeshipRemoteDistrict"`
		Video                  string        `json:"video"`
		DetailPics             string        `json:"detailPics"`
		IsSubdivision          int           `json:"isSubdivision"`
		SubdivisionId          int           `json:"subdivisionId"`
		SubdivisionName        string        `json:"subdivisionName"`
		SubdivisionRank        int           `json:"subdivisionRank"`
		DirecTCommissionType   int           `json:"directCommissionType"`
		DirectCommission       int           `json:"directCommission"`
		DirectCommissionLink   string        `json:"directCommissionLink"`
		Sales24H               int           `json:"sales24h"`
		Lowest                 int           `json:"lowest"`
		Tbcid                  int           `json:"tbcid"`
	} `json:"data"`
}

func ItemDetail(itemId string, appKeyType int8) (*ItemDetailData, error) {
	var err error
	var appKey string
	var secret string
	t := time.Now().UnixNano() / 1000000

	nonce := utils.RandNum(100000, 999999)
	if appKeyType == 1 {
		appKey = "5f5726d7b7747"
		secret = "0fd064738c4bd39eb790f91be66aa2b0"
	} else if appKeyType == 3 {
		appKey = "602f96351f26d"
		secret = "c6ab0d1ff94b0895ed749ca0b27c3af6"
	} else {
		appKey = "5d00ab04a9f3a"
		secret = "8de67b31a8b08167253b718fa565eb04"
	}

	d := &CommonData{
		appKey,
		"v1.3.0",
		strconv.FormatInt(t, 10),
		strconv.Itoa(nonce),
		"",
	}

	str := fmt.Sprintf("appKey=%s&timer=%s&nonce=%s&key=%s", d.appKey, d.timer, d.nonce, secret)

	m := md5.New()
	m.Write([]byte(str))
	d.signRan = strings.ToTitle(hex.EncodeToString(m.Sum(nil)))

	u, err := url.Parse("https://openapi.dataoke.com/api/goods/get-goods-details")
	if err != nil {
		return nil, err
	}

	p := url.Values{}

	//t := reflect.TypeOf(*d)
	//v := reflect.ValueOf(*d)
	//for k := 0; k < t.NumFiled(); k++ {
	//	fmt.Printf("%s -- %v \n", t.Filed(k).Name, v.Field(k).Interface())
	//}

	p.Set("appKey", d.appKey)
	p.Set("version", d.version)
	p.Set("timer", d.timer)
	p.Set("nonce", d.nonce)
	p.Set("signRan", d.signRan)
	p.Set("goodsId", "630305425763")

	u.RawQuery = p.Encode()
	urlPath := u.String()
	resp, err := http.Get(urlPath)
	defer func() {
		err = resp.Body.Close()
		if err != nil {
			global.Log.Info(fmt.Sprintf("resp close err %s", err.Error()))
		}
	}()

	body, _ := ioutil.ReadAll(resp.Body)

	res := &ItemDetailData{}
	_ = json.Unmarshal(body, res)

	return res, nil
}
