package utils

import (
	"github.com/casbin/casbin"
	gormadapter "github.com/casbin/gorm-adapter"
	_ "github.com/go-sql-driver/mysql"
	"gorm.io/driver/mysql"
	"gorm.io/gorm"
	"gorm.io/gorm/logger"
	"os"
	"xiaoxiong/internal/global"
)

// 读取配置文件 初始化数据库
func GormInit() *gorm.DB {
	dsn := global.CONFIG.MySql.Username + ":" + global.CONFIG.MySql.Password + "@tcp(" + global.CONFIG.MySql.Path + ")/" + global.CONFIG.MySql.Dbname + "?" + global.CONFIG.MySql.Config
	return GormMysql(dsn)
}

// 初始化Mysql数据库
func GormMysql(dsn string) *gorm.DB {
	mysqlConfig := mysql.Config{
		DSN:                       dsn,   // DSN data source name
		DefaultStringSize:         191,   // string 类型字段的默认长度
		DisableDatetimePrecision:  true,  // 禁用 datetime 精度，MySQL 5.6 之前的数据库不支持
		DontSupportRenameIndex:    true,  // 重命名索引时采用删除并新建的方式，MySQL 5.7 之前的数据库和 MariaDB 不支持重命名索引
		DontSupportRenameColumn:   true,  // 用 `change` 重命名列，MySQL 8 之前的数据库和 MariaDB 不支持重命名列
		SkipInitializeWithVersion: false, // 根据版本自动配置
	}
	db, err := gorm.Open(mysql.New(mysqlConfig), gormConfig(global.CONFIG.MySql.LogMode))
	if err != nil {
		global.Log.Panic("mysql 初始化失败！")
		os.Exit(0)
		return nil
	}

	sqlDB, _ := db.DB()
	sqlDB.SetMaxIdleConns(global.CONFIG.MySql.MaxIdleConns)
	sqlDB.SetMaxOpenConns(global.CONFIG.MySql.MaxOpenConns)
	global.Log.Debug("conn mysql succ!")
	return db

}

// 根据配置决定是否开启日志
func gormConfig(mod bool) *gorm.Config {
	if global.CONFIG.MySql.LogZap {
		return &gorm.Config{
			Logger:                                   logger.Default.LogMode(logger.Info),
			DisableForeignKeyConstraintWhenMigrating: true,
		}
	}
	if mod {
		return &gorm.Config{
			Logger:                                   logger.Default.LogMode(logger.Info),
			DisableForeignKeyConstraintWhenMigrating: true,
		}
	} else {
		return &gorm.Config{
			Logger:                                   logger.Default.LogMode(logger.Silent),
			DisableForeignKeyConstraintWhenMigrating: true,
		}
	}
}

func InitAcsbin() *casbin.Enforcer {
	dsn := global.CONFIG.MySql.Username + ":" + global.CONFIG.MySql.Password + "@tcp(" + global.CONFIG.MySql.Path + ")/" + global.CONFIG.MySql.Dbname
	a := gormadapter.NewAdapter("mysql", dsn, true)
	enforcer := casbin.NewEnforcer("rbac_model.conf", a)
	return enforcer
}
