package taobao

import (
	"encoding/json"
	"errors"
	"fmt"
	"github.com/tidwall/gjson"
	"io/ioutil"
	"net/http"
	"xiaoxiong/internal/global"
)

type TbkCouponConvertRequest struct {
	CommonRequest
	AdzoneId   string `json:"adzone_id"`
	ItemId     string `json:"item_id"`
	RelationId string `json:"relation_id"`
}

type TbkCouponConvert struct {
	TbkCouponConvertResponse struct {
		Result struct {
			ResultCode int `json:"result_code"`
			Results    struct {
				CampaignType      int    `json:"campaign_type"`
				CategoryId        int    `json:"category_id"`
				CouponClickUrl    string `json:"coupon_click_url"`
				CouponEndTime     string `json:"coupon_end_time"`
				CouponInfo        string `json:"coupon_info"`
				CouponRemainCount int    `json:"coupon_remain_count"`
				CouponStartTime   string `json:"coupon_start_time"`
				CouponTotalCount  int    `json:"coupon_total_count"`
				ItemId            int64  `json:"item_id"`
				ItemUrl           string `json:"item_url"`
				MaxCommissionRate string `json:"max_commission_rate"`
				RewardInfo        int    `json:"reward_info"`
			} `json:"results"`
		} `json:"result"`
		RequestId string `json:"request_id"`
	} `json:"tbk_coupon_convert_response"`
}

func newTbkCouponConvertRequest(itemId string, Pid string, RelationId string, appKeyType int8) *TbkCouponConvertRequest {
	c := newCommonRequest(appKeyType)

	c.Method = "taobao.tbk.coupon.convert"
	r := &TbkCouponConvertRequest{
		*c,
		Pid,
		itemId,
		RelationId,
	}

	r.Sign = generateSign(*r, appKeyType)

	if r.Sign == "" {
		return nil
	}

	return r
}

func GyInfo(itemId string, Pid string, RelationId string, appKeyType int8) (*TbkCouponConvert, error) {
	var err error

	req := newTbkCouponConvertRequest(itemId, Pid, RelationId, appKeyType)
	//fmt.Printf("%s", req)
	if req == nil {
		return nil, errors.New("签名失败")
	}
	res := &TbkCouponConvert{}

	postData, getData := getPostData(*req)

	urlPath := TaobaoUrl + "?" + getData.Encode()
	// TODO 复用client
	resp, err := http.PostForm(urlPath, postData)
	defer func() {
		err = resp.Body.Close()
		if err != nil {
			global.Log.Info(fmt.Sprintf("resp close err %s", err.Error()))
		}
	}()

	body, _ := ioutil.ReadAll(resp.Body)

	errResp := gjson.ParseBytes(body).Get("error_response")

	if errResp.Exists() {
		return nil, errors.New(errResp.Raw)
	}

	//fmt.Printf("%s\n", body)

	err = json.Unmarshal(body, res)

	return res, nil
}
