package taobao

import (
	"encoding/json"
	"errors"
	"fmt"
	"github.com/tidwall/gjson"
	"io/ioutil"
	"net/http"
	"xiaoxiong/internal/global"
)

type TbkItemInfoGetRequest struct {
	CommonRequest
	Platform string `json:"platform"`
	NumIids  string `json:"num_iids"`
}

type TbkItemInfoGet struct {
	TbkItemInfoGetResponse struct {
		Results struct {
			NTbkItem []struct {
				CatLeafName          string `json:"cat_leaf_name"`
				CatName              string `json:"cat_name"`
				FreeShipment         bool   `json:"free_shipment"`
				HotFlag              string `json:"hot_flag"`
				ItemUrl              string `json:"item_url"`
				JuOnlineEndTime      string `json:"ju_online_end_time"`
				JuOnlineStartTime    string `json:"ju_online_start_time"`
				JuPreShowEndTime     string `json:"ju_pre_show_end_time"`
				JuPreShowStartTime   string `json:"ju_pre_show_start_time"`
				MaterialLibType      string `json:"material_lib_type"`
				Nick                 string `json:"nick"`
				NumIid               string `json:"num_iid"`
				PictUrl              string `json:"pict_url"`
				PresaleDeposit       string `json:"presale_deposit"`
				PresaleEndTime       int    `json:"presale_end_time"`
				PresaleStartTime     int    `json:"presale_start_time"`
				PresaleTailEndTime   int    `json:"presale_tail_end_time"`
				PresaleTailStartTime int    `json:"presale_tail_start_time"`
				Provcity             string `json:"provcity"`
				ReservePrice         string `json:"reserve_price"`
				SellerId             int64  `json:"seller_id"`
				SmallImages          struct {
					String []string `json:"string"`
				} `json:"small_images"`
				SuperiorBrand              string `json:"superior_brand"`
				Title                      string `json:"title"`
				TmallPlayActivityEndTime   int    `json:"tmall_play_activity_end_time"`
				TmallPlayActivityStartTime int    `json:"tmall_play_activity_start_time"`
				UserType                   int    `json:"user_type"`
				Volume                     int    `json:"volume"`
				ZkFinalPrice               string `json:"zk_final_price"`
			} `json:"n_tbk_item"`
		} `json:"results"`
		RequestId string `json:"request_id"`
	} `json:"tbk_item_info_get_response"`
}

func newTbkItemInfoGetRequest(itemId string, appKeyType int8) *TbkItemInfoGetRequest {
	c := newCommonRequest(appKeyType)

	c.Method = "taobao.tbk.item.info.get"
	r := &TbkItemInfoGetRequest{
		*c,
		"2",
		itemId,
	}

	r.Sign = generateSign(*r, appKeyType)

	if r.Sign == "" {
		return nil
	}

	return r
}

func ItemDetail(itemId string, appKeyType int8) (*TbkItemInfoGet, error) {
	var err error

	req := newTbkItemInfoGetRequest(itemId, appKeyType)
	if req == nil {
		return nil, errors.New("签名失败")
	}
	res := &TbkItemInfoGet{}

	postData, getData := getPostData(*req)

	urlPath := TaobaoUrl + "?" + getData.Encode()
	// TODO 复用client
	resp, err := http.PostForm(urlPath, postData)
	defer func() {
		err = resp.Body.Close()
		if err != nil {
			global.Log.Info(fmt.Sprintf("resp close err %s", err.Error()))
		}
	}()

	body, _ := ioutil.ReadAll(resp.Body)
	//fmt.Printf("%s", body)

	errResp := gjson.ParseBytes(body).Get("error_response")

	if errResp.Exists() {
		return nil, errors.New(errResp.Raw)
	}

	err = json.Unmarshal(body, res)

	return res, nil
}
